# Contributing

Contributions are what make the open source community such an amazing
place to learn, inspire, and create.
Thank you for considering a contribution to this project.
Any contributions you make are _greatly appreciated_.

If you have a suggestion that would make this better, please fork the repo and create a pull request.
You can also simply open an issue with the tag "enhancement".

1. Fork the project
2. Create a feature branch for your changes
3. Commit your changes
4. Push to the branch
5. Open a pull request

Thanks again for considering contribution.
